BlurAnimation class
Animation that applies a blur filter to the child from begin to end sigma.
Uses ImageFiltered so the blur is applied to the child widget itself, unlike BackdropFilter which blurs the content painted behind the widget.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- GetAnimatedBuilder<
double> - BlurAnimation
- Available extensions
Constructors
-
BlurAnimation({Key? key, required Duration duration, required Duration delay, required Widget child, ValueSetter<
AnimationController> ? onComplete, required double begin, required double end, double idleValue = 0, bool autoPlayOnUpdate = false}) - Creates a BlurAnimation blurring the child widget.
Properties
- autoPlayOnUpdate → bool
-
Whether to replay the animation from the beginning when the widget is
rebuilt with a different tween.
finalinherited
-
builder
→ ValueWidgetBuilder<
double> -
The builder function that builds a widget with the current animated value.
finalinherited
- child → Widget
-
The child widget to be animated.
finalinherited
- curve → Curve
-
The animation curve to apply to the transition.
finalinherited
- delay → Duration
-
The delay duration before the animation starts playing.
finalinherited
- duration → Duration
-
The duration of the animation transition itself.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- idleValue → double
-
The idle or initial value of the animation before it starts playing.
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onComplete
→ ValueSetter<
AnimationController> ? -
A callback triggered when the animation completes.
finalinherited
-
onStart
→ ValueSetter<
AnimationController> ? -
A callback triggered when the animation starts playing.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalDuration → Duration
-
Returns the total duration including both the animation duration and the delay.
no setterinherited
-
tween
→ Tween<
double> -
The tween defining the start and end values for the animation.
finalinherited
Methods
-
blur(
{double begin = 0, double end = 15, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Blurs the widget frombegintoendsigma factor. -
bounce(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Bounces the scale of the widget frombegintoend. -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → GetAnimatedBuilderState< double> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
fadeIn(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Animates the widget's opacity from 0.0 to 1.0. -
fadeOut(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Animates the widget's opacity from 1.0 to 0.0. -
flip(
{double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Flips the widget around the Y-axis frombegintoend. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rotate(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Rotates the widget frombegintoendangle in radians. -
scale(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Scales the widget frombegintoendfactor. -
size(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Animates the widget's layout size/scale frombegintoend. -
slide(
{required OffsetBuilder offset, double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Translates/slides the widget dynamically using anoffsetbuilder. -
spin(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Spins the widget 360 degrees. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
wave(
{double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false, bool autoPlayOnUpdate = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Animates the widget with a translation wave on the Y-axis.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited