blur method

GetAnimatedBuilder blur({
  1. double begin = 0,
  2. double end = 15,
  3. Duration duration = _defaultDuration,
  4. Duration delay = _defaultDelay,
  5. ValueSetter<AnimationController>? onComplete,
  6. bool isSequential = false,
})

Blurs the widget from begin to end sigma factor.

  • begin Starting blur factor.
  • end Ending blur factor.
  • duration The duration of the blur transition.
  • delay The delay duration before blurring starts.
  • onComplete A callback triggered when the animation completes.
  • isSequential If true, starts this animation after the previous one in the chain completes.

Implementation

GetAnimatedBuilder blur({
  double begin = 0,
  double end = 15,
  Duration duration = _defaultDuration,
  Duration delay = _defaultDelay,
  ValueSetter<AnimationController>? onComplete,
  bool isSequential = false,
}) {
  return BlurAnimation(
    duration: duration,
    delay: _getDelay(isSequential, delay),
    begin: begin,
    end: end,
    onComplete: onComplete,
    child: this,
  );
}