fadeOut method

GetAnimatedBuilder fadeOut({
  1. Duration duration = _defaultDuration,
  2. Duration delay = _defaultDelay,
  3. ValueSetter<AnimationController>? onComplete,
  4. bool isSequential = false,
})

Animates the widget's opacity from 1.0 to 0.0.

  • duration The duration of the animation transition.
  • delay The delay duration before the animation starts playing.
  • onComplete A callback triggered when the animation completes.
  • isSequential If true, starts this animation after the previous one in the chain completes.

Implementation

GetAnimatedBuilder fadeOut({
  Duration duration = _defaultDuration,
  Duration delay = _defaultDelay,
  ValueSetter<AnimationController>? onComplete,
  bool isSequential = false,
}) {
  assert(isSequential || this is! FadeInAnimation,
      'Can not use fadeOut() + fadeIn when isSequential is false');

  return FadeOutAnimation(
    duration: duration,
    delay: _getDelay(isSequential, delay),
    onComplete: onComplete,
    child: this,
  );
}