flip method
GetAnimatedBuilder
flip({
- double begin = 0,
- double end = 1,
- Duration duration = _defaultDuration,
- Duration delay = _defaultDelay,
- ValueSetter<
AnimationController> ? onComplete, - bool isSequential = false,
- bool autoPlayOnUpdate = false,
Flips the widget around the Y-axis from begin to end.
beginStarting rotation value factor.endEnding rotation value factor.durationThe duration of the flip transition.delayThe delay duration before flipping starts.onCompleteA callback triggered when the animation completes.isSequentialIf true, starts this animation after the previous one in the chain completes.autoPlayOnUpdateIf true, replays the animation when rebuilt with a different tween.
Implementation
GetAnimatedBuilder flip({
double begin = 0,
double end = 1,
Duration duration = _defaultDuration,
Duration delay = _defaultDelay,
ValueSetter<AnimationController>? onComplete,
bool isSequential = false,
bool autoPlayOnUpdate = false,
}) {
return FlipAnimation(
duration: duration,
delay: _getDelay(isSequential, delay),
begin: begin,
end: end,
onComplete: onComplete,
autoPlayOnUpdate: autoPlayOnUpdate,
child: this,
);
}