rotate method
GetAnimatedBuilder
rotate({
- required double begin,
- required double end,
- Duration duration = _defaultDuration,
- Duration delay = _defaultDelay,
- ValueSetter<
AnimationController> ? onComplete, - bool isSequential = false,
Rotates the widget from begin to end angle in radians.
beginStarting rotation angle in radians.endEnding rotation angle in radians.durationThe duration of the rotation transition.delayThe delay duration before the rotation starts.onCompleteA callback triggered when the animation completes.isSequentialIf true, starts this animation after the previous one in the chain completes.
Implementation
GetAnimatedBuilder rotate({
required double begin,
required double end,
Duration duration = _defaultDuration,
Duration delay = _defaultDelay,
ValueSetter<AnimationController>? onComplete,
bool isSequential = false,
}) {
return RotateAnimation(
duration: duration,
delay: _getDelay(isSequential, delay),
begin: begin,
end: end,
onComplete: onComplete,
child: this,
);
}