slide method

GetAnimatedBuilder slide({
  1. required OffsetBuilder offset,
  2. double begin = 0,
  3. double end = 1,
  4. Duration duration = _defaultDuration,
  5. Duration delay = _defaultDelay,
  6. ValueSetter<AnimationController>? onComplete,
  7. bool isSequential = false,
})

Translates/slides the widget dynamically using an offset builder.

  • offset Callback that provides the slide offset based on the animation value.
  • begin Starting interpolation value.
  • end Ending interpolation value.
  • duration The duration of the slide transition.
  • delay The delay duration before sliding starts.
  • onComplete A callback triggered when the animation completes.
  • isSequential If true, starts this animation after the previous one in the chain completes.

Implementation

GetAnimatedBuilder slide({
  required OffsetBuilder offset,
  double begin = 0,
  double end = 1,
  Duration duration = _defaultDuration,
  Duration delay = _defaultDelay,
  ValueSetter<AnimationController>? onComplete,
  bool isSequential = false,
}) {
  return SlideAnimation(
    duration: duration,
    delay: _getDelay(isSequential, delay),
    begin: begin,
    end: end,
    onComplete: onComplete,
    offsetBuild: offset,
    child: this,
  );
}