spin method
GetAnimatedBuilder
spin({
- Duration duration = _defaultDuration,
- Duration delay = _defaultDelay,
- ValueSetter<
AnimationController> ? onComplete, - bool isSequential = false,
- bool autoPlayOnUpdate = false,
Spins the widget 360 degrees.
durationThe duration of the spin transition.delayThe delay duration before the spin starts.onCompleteA callback triggered when the animation completes.isSequentialIf true, starts this animation after the previous one in the chain completes.autoPlayOnUpdateIf true, replays the animation when rebuilt with a different tween.
Implementation
GetAnimatedBuilder spin({
Duration duration = _defaultDuration,
Duration delay = _defaultDelay,
ValueSetter<AnimationController>? onComplete,
bool isSequential = false,
bool autoPlayOnUpdate = false,
}) {
return SpinAnimation(
duration: duration,
delay: _getDelay(isSequential, delay),
onComplete: onComplete,
autoPlayOnUpdate: autoPlayOnUpdate,
child: this,
);
}