wave method
GetAnimatedBuilder
wave({
- double begin = 0,
- double end = 1,
- Duration duration = _defaultDuration,
- Duration delay = _defaultDelay,
- ValueSetter<
AnimationController> ? onComplete, - bool isSequential = false,
- bool autoPlayOnUpdate = false,
Animates the widget with a translation wave on the Y-axis.
beginStarting wave phase value.endEnding wave phase value.durationThe duration of the wave transition.delayThe delay duration before the wave starts.onCompleteA callback triggered when the animation completes.isSequentialIf true, starts this animation after the previous one in the chain completes.autoPlayOnUpdateIf true, replays the animation when rebuilt with a different tween.
Implementation
GetAnimatedBuilder wave({
double begin = 0,
double end = 1,
Duration duration = _defaultDuration,
Duration delay = _defaultDelay,
ValueSetter<AnimationController>? onComplete,
bool isSequential = false,
bool autoPlayOnUpdate = false,
}) {
return WaveAnimation(
duration: duration,
delay: _getDelay(isSequential, delay),
begin: begin,
end: end,
onComplete: onComplete,
autoPlayOnUpdate: autoPlayOnUpdate,
child: this,
);
}