builder property
The builder function that builds a widget with the current animated value.
Implementation
final ValueWidgetBuilder<T> builder;
The builder function that builds a widget with the current animated value.
final ValueWidgetBuilder<T> builder;