totalDuration property
Duration
get
totalDuration
Returns the total duration including both the animation duration and the delay.
Implementation
Duration get totalDuration => duration + delay;
Returns the total duration including both the animation duration and the delay.
Duration get totalDuration => duration + delay;