willResetOnDispose property
bool
get
willResetOnDispose
Whether the controller will be reset when this state is disposed.
Implementation
bool get willResetOnDispose => _willResetOnDispose;
Whether the controller will be reset when this state is disposed.
bool get willResetOnDispose => _willResetOnDispose;