ObxError class

Exception thrown when Obx or GetX widgets are used improperly.

This error commonly occurs if no observable variables (Rx types) are detected within the build scope of the reactive widget.

Implemented types

Constructors

ObxError()
Creates a constant instance of ObxError.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited