get_core/get_core library

Classes

Engine
Helper class to interact with the Flutter framework's bindings.
GetInterface
The base class/interface that allows other packages (like navigation, state management, etc.) to merge their capabilities into the global Get instance through Dart extensions.

Properties

Get → _GetImpl
The global entrypoint for accessing GetX APIs.
final

Functions

defaultLogWriterCallback(String value, {bool isError = false}) → void
The default log writer callback used by GetX.

Typedefs

LogWriterCallback = void Function(String text, {bool isError})
Signature for a custom log writer function callback.
ValueUpdater<T> = T Function()
Signature for a callback that returns a value of type T.