Engine class

Helper class to interact with the Flutter framework's bindings.

Constructors

Engine()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WidgetsBinding
Returns the current WidgetsBinding instance, ensuring it is initialized first.
no setter