get_instance/get_instance library

Classes

BindingsInterface<T>
An interface to define dependency injection rules for routes or specific flows.
GetxService
Unlike GetxController, which serves to control events on each of its pages, GetxService is not automatically disposed (nor can be removed with Get.delete()). It is ideal for situations where, once started, that service will remain in memory, such as Auth control for example. Only way to remove it is Get.reset().
InstanceInfo
Holds metadata about the registration and lifecycle state of an instance.

Mixins

GetLifeCycleMixin
Mixin that provides lifecycle methods for controllers.
GetxServiceMixin
Allow track difference between GetxServices and GetxControllers

Extensions

Inst on GetInterface
Main extension on GetInterface providing dependency injection features.
ResetInstance on GetInterface
Extension on GetInterface to reset and clear registered instances.

Typedefs

AsyncInstanceBuilderCallback<S> = Future<S> Function()
Callback type for asynchronously building instances of type S.
BindingBuilderCallback = void Function()
A callback used to lazily initialize or register bindings.
InstanceBuilderCallback<S> = S Function()
Callback type for building singleton or lazy instances of type S.
InstanceCreateBuilderCallback<S> = S Function(BuildContext _)
Callback type for building instances of type S on demand using BuildContext.

Exceptions / Errors

InstanceNotFoundException
Exception thrown when a requested dependency has not been registered in the dependency manager.