put<S> method
Injects a dependency into the dependency manager and immediately initializes it.
Returns the registered dependency.
tagOptional tag to identify this specific instance.permanentIf true, prevents the instance from being deleted by SmartManagement.
Implementation
S put<S>(S dependency, {String? tag, bool permanent = false}) {
_insert(
isSingleton: true,
name: tag,
permanent: permanent,
builder: (() => dependency),
);
return find<S>(tag: tag);
}