isCreate property
bool
get
isCreate
Whether the instance is created on demand rather than stored as a singleton.
Implementation
bool get isCreate => isSingleton != true;
Whether the instance is created on demand rather than stored as a singleton.
bool get isCreate => isSingleton != true;