GetLifeCycleMixin mixin
Mixin that provides lifecycle methods for controllers.
This mixin provides methods like onInit, onReady, and onClose that are called at different stages of the controller's lifecycle.
class SomeController with GetLifeCycleMixin {
@override
void onInit() {
// Initialize resources
super.onInit();
}
}
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → bool
-
Checks whether the controller has already been initialized.
no setter
- isClosed → bool
-
Checks whether the controller has already been closed.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClose(
) → void - Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
-
onDelete(
) → void - Called when the controller is removed from memory.
-
onInit(
) → void - Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
-
onReady(
) → void - Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
-
onStart(
) → void - Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited