GetModalBottomSheetRoute<T> constructor

GetModalBottomSheetRoute<T>({
  1. WidgetBuilder? builder,
  2. ThemeData? theme,
  3. String? barrierLabel,
  4. Color? backgroundColor,
  5. double? elevation,
  6. ShapeBorder? shape,
  7. bool removeTop = true,
  8. Clip? clipBehavior,
  9. Color? modalBarrierColor,
  10. bool isDismissible = true,
  11. bool enableDrag = true,
  12. bool? showDragHandle,
  13. Color? dragHandleColor,
  14. Size? dragHandleSize,
  15. Color? shadowColor,
  16. Color? surfaceTintColor,
  17. required bool isScrollControlled,
  18. RouteSettings? settings,
  19. Duration enterBottomSheetDuration = const Duration(milliseconds: 250),
  20. Duration exitBottomSheetDuration = const Duration(milliseconds: 200),
  21. Curve? curve,
})

Constructs a GetModalBottomSheetRoute.

This requires a builder that returns the widget content of the bottom sheet. Standard parameters like backgroundColor, elevation, and shape will fall back to the closest BottomSheetThemeData if omitted.

Implementation

GetModalBottomSheetRoute({
  this.builder,
  this.theme,
  this.barrierLabel,
  this.backgroundColor,
  this.elevation,
  this.shape,
  this.removeTop = true,
  this.clipBehavior,
  this.modalBarrierColor,
  this.isDismissible = true,
  this.enableDrag = true,
  this.showDragHandle,
  this.dragHandleColor,
  this.dragHandleSize,
  this.shadowColor,
  this.surfaceTintColor,
  required this.isScrollControlled,
  super.settings,
  this.enterBottomSheetDuration = const Duration(milliseconds: 250),
  this.exitBottomSheetDuration = const Duration(milliseconds: 200),
  this.curve,
}) {
  RouterReportManager.instance.reportCurrentRoute(this);
}