GetNavigationExt extension
- on
Properties
- arguments → dynamic
-
Available on GetInterface, provided by the GetNavigationExt extension
give current argumentsno setter - context → BuildContext?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to currentContextno setter - currentRoute → String
-
Available on GetInterface, provided by the GetNavigationExt extension
give name from current routeno setter - defaultDialogTransitionCurve → Curve
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultDialogTransitionDuration → Duration
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultOpaqueRoute → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultPopGesture → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransition → Transition?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransitionCurve → Curve
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransitionDuration → Duration
-
Available on GetInterface, provided by the GetNavigationExt extension
The transition duration applied to routes that don't set their own: thetransitionDurationgiven toGetMaterialApp/GetCupertinoApp, or 300 milliseconds when none was provided.no setter - deviceLocale → Locale?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - engine → WidgetsBinding
-
Available on GetInterface, provided by the GetNavigationExt extension
The current null safe WidgetsBindingno setter - isBottomSheetOpen → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
check if bottomsheet is open, or null if routing is not initialized yetno setter - isDialogOpen → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
check if dialog is open, or null if routing is not initialized yetno setter - isOpaqueRouteDefault → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
check if default opaque route is enableno setter - isOverlaysClosed → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Returns true if there is no Snackbar, Dialog or BottomSheet openno setter - isOverlaysOpen → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Returns true if a Snackbar, Dialog or BottomSheet is currently OPENno setter - isSnackbarOpen → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
check if snackbar is open, or false if routing is not initialized yetno setter -
key
→ GlobalKey<
NavigatorState> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter -
keys
→ Map<
String, GetDelegate> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter - overlayContext → BuildContext?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to current Overlay Contextno setter -
parameters
→ Map<
String, String?> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter - previousRoute → String
-
Available on GetInterface, provided by the GetNavigationExt extension
give name from previous routeno setter - rawRoute → Route?
-
Available on GetInterface, provided by the GetNavigationExt extension
check a raw current routeno setter - rootController → GetRootState
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - routing → Routing
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - theme → ThemeData
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to Theme.of(context)no setter - window → PlatformDispatcher
-
Available on GetInterface, provided by the GetNavigationExt extension
The window to which this binding is bound.no setter
Methods
-
addKey(
GlobalKey< NavigatorState> newKey) → GlobalKey<NavigatorState> ? -
Available on GetInterface, provided by the GetNavigationExt extension
-
appUpdate(
) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
args<
T> () → T -
Available on GetInterface, provided by the GetNavigationExt extension
-
back<
T> ({T? result, bool canPop = true, int times = 1, String? id}) → bool -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popUntil() shortcut.
-
backLegacy<
T> ({T? result, bool closeOverlays = false, bool canPop = true, int times = 1, String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
changeTheme(
ThemeData theme) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
changeThemeMode(
ThemeMode themeMode) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
close<
T extends Object> ({bool closeAll = true, bool closeSnackbar = true, bool closeDialog = true, bool closeBottomSheet = true, String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Closes the currently open snackbars, dialogs and bottom sheets. -
closeAllBottomSheets<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Close all currently open bottom sheets, returning aresultto each of them, if provided -
closeAllDialogs<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Close all currently open dialogs, returning aresultto each of them, if provided -
closeAllDialogsAndBottomSheets(
String? id) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllOverlays(
) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllSnackbars(
{bool withAnimations = true}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Closes all queued snackbars. -
closeBottomSheet<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeCurrentSnackbar(
{bool withAnimations = true}) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension
Closes the currently visible snackbar, if any. -
closeDialog<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Close the currently open dialog, returning aresult, if provided -
closeOverlay<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Close the current overlay (e.g. dialog or bottom sheet) returning theresult, if provided. -
delegate<
TDelegate extends RouterDelegate< (TPage> , TPage>) → TDelegate? -
Available on GetInterface, provided by the GetNavigationExt extension
Casts the stored router delegate to a desired type -
forceAppUpdate(
) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension
As a rule, Flutter knows which widget to update, so this command is rarely needed. We can mention situations where you use const so that widgets are not updated with setState, but you want it to be forcefully updated when an event like language change happens. using context to make the widget dirty for performRebuild() is a viable solution. However, in situations where this is not possible, or at least, is not desired by the developer, the only solution for updating widgets that Flutter does not want to update is to use reassemble to forcibly rebuild all widgets. Attention: calling this function will reconstruct the application from the sketch, use this with caution. Your entire application will be rebuilt, and touch events will not work until the end of rendering. -
nestedKey(
String? key) → GetDelegate? -
Available on GetInterface, provided by the GetNavigationExt extension
-
off<
T> (Widget page(), {bool? opaque, Transition? transition, Curve? curve, bool? popGesture, String? id, String? routeName, Object? arguments, List< BindingsInterface> bindings = const [], bool fullscreenDialog = false, bool preventDuplicates = true, Duration? duration, double gestureWidth(BuildContext context)?, CustomTransition? customTransition}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushReplacement() shortcut .
-
offAll<
T> (Widget page(), {bool predicate(GetPage)?, bool? opaque, bool? popGesture, String? id, String? routeName, Object? arguments, List< BindingsInterface> bindings = const [], bool fullscreenDialog = false, Transition? transition, Curve? curve, Duration? duration, double gestureWidth(BuildContext context)?, CustomTransition? customTransition}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Push apageand pop several pages in the stack untilpredicatereturns true.predicateis optional -
offAllNamed<
T> (String newRouteName, {Object? arguments, String? id, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamedAndRemoveUntil() shortcut.
-
offAndToNamed<
T> (String page, {Object? arguments, String? id, Object? result, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popAndPushNamed() shortcut.
-
offNamed<
T> (String page, {Object? arguments, String? id, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushReplacementNamed() shortcut.
-
offNamedUntil<
T> (String page, bool predicate(GetPage)?, {String? id, Object? arguments, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamedAndRemoveUntil() shortcut.
-
offUntil<
T> (Widget page(), bool predicate(GetPage), [Object? arguments, String? id]) → Future< T?> -
Available on GetInterface, provided by the GetNavigationExt extension
-
removeRoute(
String name, {String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.removeRoute() shortcut.
-
searchDelegate(
String? k) → GetDelegate -
Available on GetInterface, provided by the GetNavigationExt extension
-
to<
T extends Object?> (Widget page(), {bool? opaque, Transition? transition, Curve? curve, Duration? duration, String? id, String? routeName, bool fullscreenDialog = false, Object? arguments, List< BindingsInterface> bindings = const [], bool preventDuplicates = true, bool? popGesture, bool showCupertinoParallax = true, double gestureWidth(BuildContext context)?, CustomTransition? customTransition, bool rebuildStack = true, PreventDuplicateHandlingMode preventDuplicateHandlingMode = PreventDuplicateHandlingMode.reorderRoutes}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.push() shortcut.
-
toNamed<
T> (String page, {Object? arguments, String? id, bool preventDuplicates = true, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamed() shortcut.
-
until(
bool predicate(GetPage), {String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popUntil() shortcut.
-
updateLocale(
Locale l) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension