isBottomSheetOpen property
bool?
get
isBottomSheetOpen
check if bottomsheet is open, or null if routing is not initialized yet
Implementation
bool? get isBottomSheetOpen => _routingOrNull?.isBottomSheet;
check if bottomsheet is open, or null if routing is not initialized yet
bool? get isBottomSheetOpen => _routingOrNull?.isBottomSheet;