isDialogOpen property
bool?
get
isDialogOpen
check if dialog is open, or null if routing is not initialized yet
Implementation
bool? get isDialogOpen => _routingOrNull?.isDialog;
check if dialog is open, or null if routing is not initialized yet
bool? get isDialogOpen => _routingOrNull?.isDialog;