localeSetExplicitly property

bool localeSetExplicitly
getter/setter pair

Whether the app locale was chosen explicitly through Get.updateLocale.

Once set, didChangeLocales stops following the device locale, even if the explicitly chosen locale happens to be identical to the last locale that was auto-applied from the device. Automatic device-locale adoption never sets this flag.

Implementation

bool localeSetExplicitly = false;