Translations class abstract
The base abstract class used for providing localized translations to the app.
Extend this class to define the key-value dictionary of strings per language.
Then pass the subclass instance to translations in GetMaterialApp or GetCupertinoApp.
Example:
class MyTranslations extends Translations {
@override
Map<String, Map<String, String>> get keys => {
'en_US': {'hello': 'Hello World'},
'pt_BR': {'hello': 'Olá Mundo'}
};
}
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited