keys property

Map<String, Map<String, String>> get keys

Defines the localization dictionary.

The outer map key represents the Locale identifier (e.g. en_US or pt_BR), and the inner map represents the string keys and their translated values.

Implementation

Map<String, Map<String, String>> get keys;