currentBindingOwnerName property

String? get currentBindingOwnerName

The route name new dependency registrations should be attributed to, or null when none is in scope. Read by the instance manager when a registration is created.

Implementation

String? get currentBindingOwnerName => _bindingOwnerName;