get_navigation/src/routes/index library

Classes

BackButtonCallback
CircularRevealClipper
A custom clipper that creates a circular reveal animation effect.
CircularRevealTransition
CustomTransition
Abstract class for defining custom page transitions.
Dependencies
FadeInTransition
GetBackGestureController<T>
GetBackGestureDetector<T>
GetBackGestureDetectorState<T>
GetDelegate
GetInformationParser
GetMiddleware
The Page Middlewares. The Functions will be called in this order (( redirect -> onPageCalled -> onBindingsStart -> onPageBuildStart -> onPageBuilt -> onPageDispose ))
GetNavigator
A Navigator preconfigured for GetX's Router (Navigator 2.0) flow.
GetObserver
GetPage<T>
GetPageRoute<T>
GetRouteInformationProvider
A RouteInformationProvider that keeps the platform (browser) history in sync with the page stack managed by a GetDelegate.
GetRouterOutlet
GetTransitionDelegate<T>
A TransitionDelegate that resolves page-list changes like the framework's DefaultTransitionDelegate, except while isPopNavigation reports that the change being applied was caused by a back navigation.
IndexedRouteBuilder<T>
InheritedNavigator
LeftToRightFadeTransition
MiddlewareRunner
Module
ModuleState
NoTransition
PageRedirect
PageSettings
ParseRouteTree
PathDecoded
RightToLeftFadeTransition
RouteDecoder
RouteListenerState
RouteReport
RouteReportState
RouterListener
RouterListenerInherited
RouterListenerState
RouterOutlet<TDelegate extends RouterDelegate<T>, T extends Object>
RouterOutletState<TDelegate extends RouterDelegate<T>, T extends Object>
Routing
SizeTransitions
SlideDownTransition
SlideLeftTransition
SlideRightTransition
SlideTopTransition
ZoomInTransition

Enums

PopMode
Enables the user to customize the intended pop behavior
PreventDuplicateHandlingMode
Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates
Transition

Mixins

GetPageRouteTransitionMixin<T>
IGetNavigation
PageRouteReportMixin<T>
Mixin that reports route lifecycle events to the RouterReportManager.
RouteReportMixin<T extends StatefulWidget>
Mixin that reports route lifecycle events to the RouterReportManager.
RouterListenerMixin<T extends StatefulWidget>

Functions

removeLastHistory(String? url) → void
setUrlStrategy() → void

Typedefs

GetPageBuilder = Widget Function()
GetRouteAwarePageBuilder<T> = Widget Function([GetPageRoute<T>? route])

Exceptions / Errors