arguments<T> method

T arguments<T>()

The arguments of the page currently being built, falling back to the arguments of the top-most entry of activePages outside of a page build, so that pages pushed within the same frame each observe their own arguments.

Implementation

T arguments<T>() {
  final building = _buildingPageSettings;
  if (building != null) return building.arguments as T;
  return currentConfiguration?.pageSettings?.arguments as T;
}