parameters property

Map<String, String> get parameters

The parameters of the page currently being built, falling back to the parameters of the top-most entry of activePages outside of a page build (see arguments).

While middlewares of an in-flight navigation are being resolved, the parameters of the route being resolved (PageRedirect.resolvingParameters) take precedence, so that middlewares observe the parameters of the navigation they are deciding on instead of the previous route's.

Implementation

Map<String, String> get parameters {
  final resolving = PageRedirect.resolvingParameters;
  if (resolving != null) return resolving;
  final building = _buildingPageSettings;
  if (building != null) return building.params;
  return currentConfiguration?.pageSettings?.params ?? {};
}