userInputForm property
A TextFormField in case you want a simple user input.
Every other widget is ignored if this is not null.
Implementation
final Form? userInputForm;
A TextFormField in case you want a simple user input.
Every other widget is ignored if this is not null.
final Form? userInputForm;