get_rx/get_rx library

Classes

Rx<T>
Foundation class used for custom Types outside the common native Dart types. For example, any custom "Model" class, like User().obs will use Rx as wrapper.
RxBool
RxDouble
Rx class for double type.
RxInt
Rx class for int type.
RxInterface<T>
This class is the foundation for all reactive (Rx) classes that make Get so powerful.
RxList<E>
Create a list similar to List<T> but reactive.
RxMap<K, V>
Create a map similar to Map<K, V> but reactive.
Rxn<T>
RxnBool
RxnDouble
Rx class for nullable double type.
RxnInt
Rx class for nullable int type.
RxnNum
Rx class for nullable num type.
RxnString
Rx class for nullable String type.
RxNum
Rx class for num type.
RxSet<E>
Create a set similar to Set<T> but reactive.
RxString
Rx class for String type.
Worker
Workers

Mixins

RxObjectMixin<T>
global object that registers against GetX and Obx, and allows the reactivity of those Widgets and Rx values.

Extensions

BoolExtension on bool
DoubleExtension on double
IntExtension on int
ListExtension on List<E>
MapExtension on Map<K, V>
RxBoolExt on Rx<bool>
RxDoubleExt on Rx<double>
Extension on Rx<double> providing basic double operators.
RxIntExt on Rx<int>
Extension on Rx<int> providing basic integer operators.
RxnBoolExt on Rx<bool?>
RxnDoubleExt on Rx<double?>
Extension on Rx<double?> providing basic double operators.
RxnIntExt on Rx<int?>
Extension on Rx<int?> providing basic integer operators.
RxnNumExt on Rx<T?>
Extension on Rx<num?> providing basic operators.
RxnStringExt on Rx<String?>
Extension on Rx<String?> providing standard operators.
RxNumExt on Rx<T>
Extension on Rx<num> providing basic operators.
RxStringExt on Rx<String>
Extension on Rx<String> providing standard operators.
RxT on T
RxTnew on Object
This method will replace the old .obs method. It's a breaking change, but it is essential to avoid conflicts with the new dart 3 features. T will be inferred by contextual type inference rather than the extension type.
SetExtension on Set<E>
StringExtension on String

Functions

debounce<T>(GetListenable<T> listener, WorkerCallback<T> callback, {Duration? time, Function? onError, void onDone()?, bool? cancelOnError}) Worker
debounce is similar to interval, but sends the last value. Useful for Anti DDos, every time the user stops typing for 1 second, for instance. When listener emits the last "value", when time hits, it calls callback with the last "value" emitted.
ever<T>(GetListenable<T> listener, WorkerCallback<T> callback, {Object? condition = true, Function? onError, void onDone()?, bool? cancelOnError}) Worker
Called every time listener changes. As long as the condition returns true.
everAll(List<RxInterface> listeners, WorkerCallback callback, {Object? condition = true, Function? onError, void onDone()?, bool? cancelOnError}) Worker
Similar to ever, but takes a list of listeners, the condition for the callback is common to all listeners, and the callback is executed to each one of them. The Worker is common to all, so worker.dispose() will cancel all streams.
interval<T>(GetListenable<T> listener, WorkerCallback<T> callback, {Duration time = const Duration(seconds: 1), Object? condition = true, Function? onError, void onDone()?, bool? cancelOnError}) Worker
Ignore all changes in listener during time (1 sec by default) or until condition is met (can be a bool expression or a bool Function()), It brings the 1st "value" since the period of time, so if you click a counter button 3 times in 1 sec, it will show you "1" (after 1 sec of the first press) click counter 3 times in 1 sec, it will show you "4" (after 1 sec) click counter 2 times in 1 sec, it will show you "7" (after 1 sec).
once<T>(GetListenable<T> listener, WorkerCallback<T> callback, {Object? condition = true, Function? onError, void onDone()?, bool? cancelOnError}) Worker
once() will execute only 1 time when condition is met and cancel the subscription to the listener stream right after that. condition defines when callback is called, and can be a bool or a bool Function().

Typedefs

WorkerCallback<T> = dynamic Function(T callback)