get_state_manager/get_state_manager library

Classes

Bind<T>
BindElement<T>
The BindElement is responsible for injecting dependencies into the widget tree so that they can be observed
Binder<T>
Binds
CustomStatus<T>
EmptyStatus<T>
ErrorStatus<T, S>
FullLifeCycleController
A controller that can observe the full app lifecycle.
GetBuilder<T extends GetxController>
GetListenable<T>
GetNotifier<T>
GetResponsiveView<T>
A responsive view that extends GetView with responsive capabilities.
GetStatus<T>
Sealed class representing different states of a notifier.
GetTickerProvider
Common interface of GetSingleTickerProviderStateMixin and GetTickerProviderStateMixin: a TickerProvider whose tickers follow the TickerMode of the widget subtree that forwards its dependency changes to didChangeDependencies.
GetView<T>
GetView is a lightweight StatelessWidget providing easy access to a controller registered in dependency injection without calling Get.find<Controller>() manually.
GetxController
A base controller class that provides state management functionality.
LoadingStatus<T>
Observer
An experimental widget that observes reactive changes.
Obx
The simplest reactive widget in GetX.
ObxElement
Element for Obx widgets that tracks reactive dependencies.
ObxStatelessWidget
A StatelessWidget that can listen to reactive changes.
ObxValue<T extends RxInterface>
Similar to Obx, but manages a local state. Pass the initial data in constructor. Useful for simple local states, like toggles, visibility, themes, button states, etc. Sample: ObxValue((data) => Switch( value: data.value, onChanged: (flag) => data.value = flag, ), false.obs, ),
ObxWidget
The ObxWidget is the base for all GetX reactive widgets
ResponsiveScreen
Provides information about the current screen.
ResponsiveScreenSettings
Settings for responsive screen breakpoints.
RxController
A base controller class for reactive state management using Rx variables.
StateController<T>
A controller that manages state for asynchronous operations.
SuccessStatus<T>
SuperController<T>
A controller that combines full lifecycle management with state management.
Value<T>
ValueBuilder<T>
Manages a local state like ObxValue, but uses a callback instead of a Rx value.
ValueBuilderState<T>
The state for ValueBuilder.

Enums

ScreenType
Enum representing different screen types.

Mixins

FullLifeCycleMixin
A mixin that provides full lifecycle callbacks for the controller.
GetResponsiveMixin
Mixin that provides responsive building capabilities.
GetRestorationMixin
A mixin that provides Flutter state restoration support to GetLifeCycleMixin controllers.
GetSingleTickerProviderStateMixin
Used like SingleTickerProviderMixin but only with Get Controllers. Simplifies AnimationController creation inside GetxController.
GetTickerProviderStateMixin
Used like TickerProviderMixin but only with Get Controllers. Simplifies multiple AnimationController creation inside GetxController.
ScrollMixin
A mixin that provides scroll-based data fetching capabilities.
StatelessObserverComponent
Mixin that adds reactive tracking to StatelessElement.
StateMixin<T>
Mixin that adds state management with status tracking.

Typedefs

FuturizeCallback<T> = Future<T> Function(VoidCallback fn)
GetControllerBuilder<T extends GetLifeCycleMixin> = Widget Function(T controller)
GetState<T> = GetStatus<T>
InitBuilder<T> = T Function()
NotifierBuilder<T> = Widget Function(T state)
ValueBuilderBuilder<T> = Widget Function(T snapshot, ValueBuilderUpdateCallback<T> updater)
Builder function for ValueBuilder.
ValueBuilderUpdateCallback<T> = void Function(T snapshot)
Callback function to update the value in ValueBuilder.
VoidCallback = void Function()
WidgetCallback = Widget Function()

Exceptions / Errors

BindError<T>