EmptyStatus<T> class

Inheritance
Available extensions

Constructors

EmptyStatus()

Properties

data → T?
no setterinherited
error Object?
no setterinherited
errorMessage String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isCustom bool
no setterinherited
isEmpty bool
no setterinherited
isError bool
no setterinherited
isLoading bool
no setterinherited
isSuccess bool
no setterinherited
props List
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

maybeWhen<R>({required R orElse(), R loading()?, R success(T data)?, R error(Object? error)?, R empty()?, R custom()?}) → R

Available on GetStatus<T>, provided by the StatusDataExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<R>({required R loading(), required R success(T data), required R error(Object? error), required R empty(), R custom()?}) → R

Available on GetStatus<T>, provided by the StatusDataExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited