setError method
Sets the status to error with the given error object.
Implementation
void setError(Object error) {
change(GetStatus<T>.error(error));
}
Sets the status to error with the given error object.
void setError(Object error) {
change(GetStatus<T>.error(error));
}