setSuccess method
void
setSuccess(
- T data
Sets the status to success with the given data.
Implementation
void setSuccess(T data) {
change(GetStatus<T>.success(data));
}
Sets the status to success with the given data.
void setSuccess(T data) {
change(GetStatus<T>.success(data));
}