error property
Object?
get
error
The error object if this is an error status.
Implementation
Object? get error {
if (this is ErrorStatus) {
return (this as ErrorStatus).error;
}
return null;
}
The error object if this is an error status.
Object? get error {
if (this is ErrorStatus) {
return (this as ErrorStatus).error;
}
return null;
}