SuccessStatus<T> class

Represents a success status with data.

Inheritance
Available extensions

Constructors

SuccessStatus(T data)
const

Properties

data → T
final
data → T?

Available on GetStatus<T>, provided by the StatusDataExt extension

The data if this is a success status.
no setter
error Object?

Available on GetStatus<T>, provided by the StatusDataExt extension

The error object if this is an error status.
no setter
errorMessage String

Available on GetStatus<T>, provided by the StatusDataExt extension

The error message as a string.
no setter
hashCode int
The hash code for this object.
no setterinherited
isCustom bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Whether this status is custom.
no setter
isEmpty bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Whether this status is empty.
no setter
isError bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Whether this status is error.
no setter
isLoading bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Whether this status is loading.
no setter
isSuccess bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Whether this status is success.
no setter
props List
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited