Value<T> class

Inheritance
Implemented types
Mixed-in types
Implementers
Available extensions

Constructors

Value(T val)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasSubscribers bool
Returns true if there is at least one active listener.
no setterinherited
isDisposed bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → T
no setterinherited
status GetStatus<T>
getter/setter pairinherited
value ↔ T
The current value of the object.
getter/setter pairoverride

Methods

addListener(VoidCallback listener) Disposer
Register a closure to be called when the object changes.
inherited
addListenerId(Object? key, VoidCallback listener) Disposer
Adds a listener to a specific group identified by key.
inherited
call([T? v]) → T?
change(T? newState, {GetStatus<T>? status}) → void
inherited
containsId(Object id) bool
Checks if a listener group with the given ID exists.
inherited
dispose() → void
Disposes all listener groups.
inherited
disposeId(Object id) → void
Disposes a specific listener group.
inherited
ensureGroupListenable(Object id) ChangeNotifier
Ensures a group ChangeNotifier exists for id and returns it.
inherited
futurize(Future<T> body(), {T? initialData, String? errorMessage, bool useEmpty = true}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyGroupChildrens(Object id) → void
Reports that a listener group was read.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
obx(NotifierBuilder<T> widget, {Widget onError(String? error)?, Widget? onLoading, Widget? onEmpty, WidgetBuilder? onCustom}) Widget

Available on StateMixin<T>, provided by the StateExt extension

refresh() → void
Notifies all listeners to update using Flutter's native ChangeNotifier.
inherited
refreshGroup(Object id) → void
Refreshes only the listeners in a specific group.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeListenerId(Object id, VoidCallback listener) → void
Removes a listener from a specific group.
inherited
reportAdd(VoidCallback disposer) → void
Reports a disposer callback to the global notifier.
inherited
reportRead() → void
Reports that this notifier was read.
inherited
setEmpty() → void
inherited
setError(Object error) → void
inherited
setLoading() → void
inherited
setSuccess(T data) → void
inherited
toJson() Object?
toString() String
A string representation of this object.
override
update(T fn(T? value)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited