reportRead method
Reports that this notifier was read.
This is used by the reactive system to track dependencies.
Implementation
@protected
void reportRead() {
Notifier.instance.read(this);
}
Reports that this notifier was read.
This is used by the reactive system to track dependencies.
@protected
void reportRead() {
Notifier.instance.read(this);
}