desktopChangePoint property
When the width is greater than this value, the display will be set as ScreenType.desktop.
Implementation
final double desktopChangePoint;
When the width is greater than this value, the display will be set as ScreenType.desktop.
final double desktopChangePoint;