tabletChangePoint property

double tabletChangePoint
final

When the width is greater than this value, the display will be set as ScreenType.tablet, or when width is greater than watchChangePoint and smaller than this value, the display will be ScreenType.phone.

Implementation

final double tabletChangePoint;