message property
Optional description of why the bind failed; when provided it is used verbatim instead of the generic "no ancestor found" message.
Implementation
final String? message;
Optional description of why the bind failed; when provided it is used verbatim instead of the generic "no ancestor found" message.
final String? message;