GetView<T> class abstract

GetView is a great way of quickly access your Controller without having to call Get.find<AwesomeController>() yourself.

Sample:

class AwesomeController extends GetxController {
  final String title = 'My Awesome View';
}

class AwesomeView extends GetView<AwesomeController> {
  /// if you need you can pass the tag for
  /// Get.find<AwesomeController>(tag:"myTag");
  @override
  final String tag = "myTag";

  AwesomeView({super.key});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(20),
      child: Text( controller.title ),
    );
  }
}
``
Inheritance
Implementers
Available extensions

Constructors

GetView({Key? key})
const

Properties

controller → T
no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
final

Methods

blur({double begin = 0, double end = 15, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

bounce({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fadeIn({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

fadeOut({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

flip({double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

scale({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

size({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

slide({required OffsetBuilder offset, double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

spin({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
wave({double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited