controller property
T
get
controller
Gets the controller instance from the dependency injection container.
Implementation
T get controller => Get.find<T>(tag: tag)!;
Gets the controller instance from the dependency injection container.
T get controller => Get.find<T>(tag: tag)!;