GetWidget<S extends GetLifeCycleMixin> class
abstract
GetWidget is a great way of quickly access your individual Controller
without having to call Get.find<AwesomeController>() yourself.
Get save you controller on cache, so, you can to use Get.create() safely
GetWidget is perfect to multiples instance of a same controller. Each
GetWidget will have your own controller, and will be call events as onInit
and onClose when the controller get in/get out on memory.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- GetWidgetCache
- GetWidget
- Implementers
- Available extensions
Properties
- controller → S
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
final
Methods
-
blur(
{double begin = 0, double end = 15, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Blurs the widget frombegintoendsigma factor. -
bounce(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Bounces the scale of the widget frombegintoend. -
build(
BuildContext context) → Widget -
createElement(
) → GetWidgetCacheElement -
Inflates this configuration to a concrete instance.
inherited
-
createWidgetCache(
) → WidgetCache< GetWidgetCache> -
Creates the WidgetCache instance for this widget.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
fadeIn(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Animates the widget's opacity from 0.0 to 1.0. -
fadeOut(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Animates the widget's opacity from 1.0 to 0.0. -
flip(
{double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Flips the widget around the Y-axis frombegintoend. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rotate(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Rotates the widget frombegintoendangle in radians. -
scale(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Scales the widget frombegintoendfactor. -
size(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Animates the widget's layout size/scale frombegintoend. -
slide(
{required OffsetBuilder offset, double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Translates/slides the widget dynamically using anoffsetbuilder. -
spin(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Spins the widget 360 degrees. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
wave(
{double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Animates the widget with a translation wave on the Y-axis.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited