createWidgetCache abstract method

  1. @protected
  2. @factory
WidgetCache<GetWidgetCache> createWidgetCache()

Creates the WidgetCache instance for this widget.

This method is called when the element is created and should return a new instance of the cache that will manage this widget's state.

Implementation

@protected
@factory
WidgetCache createWidgetCache();