onClose method
Called when the cache is disposed (widget is unmounted).
Override this method to perform cleanup logic such as disposing controllers, closing streams, or releasing resources.
Implementation
@protected
@mustCallSuper
void onClose() {}
Called when the cache is disposed (widget is unmounted).
Override this method to perform cleanup logic such as disposing controllers, closing streams, or releasing resources.
@protected
@mustCallSuper
void onClose() {}