onInit method
Called when the cache is initialized (widget is mounted).
Override this method to perform initialization logic such as setting up controllers, listeners, or other resources.
Implementation
@protected
@mustCallSuper
void onInit() {}
Called when the cache is initialized (widget is mounted).
Override this method to perform initialization logic such as setting up controllers, listeners, or other resources.
@protected
@mustCallSuper
void onInit() {}