GetStateUpdate typedef
GetStateUpdate =
void Function()
Callback function to update state.
This is used to trigger widget rebuilds when state changes.
Implementation
typedef GetStateUpdate = void Function();
Callback function to update state.
This is used to trigger widget rebuilds when state changes.
typedef GetStateUpdate = void Function();