ListNotifierSingleMixin mixin

Mixin that adds single listener functionality to ChangeNotifier.

This mixin leverages Flutter's native ChangeNotifier engine under the hood for optimized $O(1)$ listener management.

Superclass constraints
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasSubscribers bool
Returns true if there is at least one active listener.
no setter
isDisposed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) Disposer
Register a closure to be called when the object changes.
override
dispose() → void
Disposes the notifier and cleans up native ChangeNotifier listeners.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onCancel() → void
Called when the last remaining listener is removed.
onListen() → void
Called when a first listener is added after having none.
refresh() → void
Notifies all listeners to update using Flutter's native ChangeNotifier.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
override
reportAdd(VoidCallback disposer) → void
Reports a disposer callback to the global notifier.
reportRead() → void
Reports that this notifier was read.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited