add method
Adds a disposer callback to the current notification data.
Implementation
void add(VoidCallback listener) {
_notifyData?.disposers.add(listener);
}
Adds a disposer callback to the current notification data.
void add(VoidCallback listener) {
_notifyData?.disposers.add(listener);
}