append<T> method
Executes a builder function with reactive tracking.
This method sets up the tracking context, executes the builder, and ensures that reactive dependencies were properly tracked.
Implementation
T append<T>(NotifyData data, T Function() builder) {
_notifyData = data;
final result = builder();
if (data.disposers.isEmpty && data.throwException) {
throw const ObxError();
}
_notifyData = null;
return result;
}