NotifyData class

Data container for reactive notification tracking.

This class holds the updater callback and list of disposers that are used during reactive tracking in widgets.

Constructors

NotifyData({required GetStateUpdate updater, required List<VoidCallback> disposers, bool throwException = true})
const

Properties

disposers List<VoidCallback>
List of disposers to clean up listeners.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
throwException bool
Whether to throw an exception if no dependencies were tracked.
final
updater GetStateUpdate
The callback to update the widget when dependencies change.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited