get_utils/get_utils library
Classes
- DeepCollectionEquality
-
DefaultEquality<
E> - GetPlatform
- GetQueue
-
IdentityEquality<
E> - Equality of objects that compares only the identity of the objects.
-
IEquality<
E> - A generic equality relation on objects.
-
IterableEquality<
E> - Equality on iterables.
-
ListEquality<
E> - Equality on lists.
-
MapEquality<
K, V> - Equality on maps.
-
SetEquality<
E> - Equality of sets.
-
UnorderedIterableEquality<
E> - Equality of the elements of two iterables without considering order.
Enums
- PluralCase
- The CLDR plural categories used to pick the correct plural form of a translation key for a given count.
Mixins
Extensions
- ContextExt on BuildContext
-
IterableExtensions
on Iterable<
T> -
Useful extensions for
Iterable. - LocalesIntl on GetInterface
- LoopEventsExt on GetInterface
- Trans on String
Typedefs
- PluralResolver = PluralCase Function(int count, Locale? locale)
-
Maps a
countunderlocaleto the PluralCase whose translation should be used. Installed through LocalesIntl.pluralResolver.