find<T> method
Finds the registered dependency of type T using Get DI container.
Implementation
T find<T>({String? tag}) => Get.find<T>(tag: tag);
Finds the registered dependency of type T using Get DI container.
T find<T>({String? tag}) => Get.find<T>(tag: tag);