get_utils/src/extensions/export library

Enums

PluralCase
The CLDR plural categories used to pick the correct plural form of a translation key for a given count.

Extensions

ContextExt on BuildContext
IterableExtensions on Iterable<T>
Useful extensions for Iterable.
LocalesIntl on GetInterface
LoopEventsExt on GetInterface
Trans on String

Typedefs

PluralResolver = PluralCase Function(int count, Locale? locale)
Maps a count under locale to the PluralCase whose translation should be used. Installed through LocalesIntl.pluralResolver.