get_utils/src/extensions/internationalization library

Enums

PluralCase
The CLDR plural categories used to pick the correct plural form of a translation key for a given count.

Typedefs

PluralResolver = PluralCase Function(int count, Locale? locale)
Maps a count under locale to the PluralCase whose translation should be used. Installed through LocalesIntl.pluralResolver.