route_manager library

Get Navigator allows you to navigate routes, open snackbars, dialogs and bottomsheets easily, and without the need for context.

Classes

BackButtonCallback
CircularRevealClipper
A custom clipper that creates a circular reveal animation effect.
CircularRevealTransition
CustomTransition
Abstract class for defining custom page transitions.
Dependencies
Engine
FadeInTransition
GetBackGestureController<T>
GetBackGestureDetector<T>
GetBackGestureDetectorState<T>
GetCupertinoApp
A fully customized CupertinoApp designed to be the entry point for GetXify applications.
GetDelegate
GetInformationParser
GetInterface
GetInterface allows any auxiliary package to be merged into the "Get" class through extensions
GetMaterialApp
A fully customized MaterialApp designed to be the entry point for GetXify applications.
GetMiddleware
The Page Middlewares. The Functions will be called in this order (( redirect -> onPageCalled -> onBindingsStart -> onPageBuildStart -> onPageBuilt -> onPageDispose ))
GetModalBottomSheetRoute<T>
A customized PopupRoute used to display a modal bottom sheet.
GetNavigator
GetObserver
GetPage<T>
GetPageRoute<T>
GetRouterOutlet
GetSnackBar
GetSnackBarState
IndexedRouteBuilder<T>
InheritedNavigator
LeftToRightFadeTransition
MiddlewareRunner
Module
ModuleState
NoTransition
PageRedirect
PageSettings
ParseRouteTree
PathDecoded
RightToLeftFadeTransition
RouteDecoder
RouteListenerState
RouteReport
RouteReportState
RouterListener
RouterListenerInherited
RouterListenerState
RouterOutlet<TDelegate extends RouterDelegate<T>, T extends Object>
RouterOutletState<TDelegate extends RouterDelegate<T>, T extends Object>
Routing
SizeTransitions
SlideDownTransition
SlideLeftTransition
SlideRightTransition
SlideTopTransition
SnackbarController
SnackBarQueue
Translations
The base abstract class used for providing localized translations to the app.
ZoomInTransition

Enums

PopMode
Enables the user to customize the intended pop behavior
PreventDuplicateHandlingMode
Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates
RowStyle
SmartManagement
GetX by default disposes unused controllers from memory, Through different behaviors. SmartManagement.full SmartManagement.full is the default one. Dispose classes that are not being used and were not set to be permanent. In the majority of the cases you will want to keep this config untouched. If you new to GetX then don't change this. SmartManagement.onlyBuilder only controllers started in init: or loaded into a Binding with Get.lazyPut() will be disposed. If you use Get.put() or Get.putAsync() or any other approach, SmartManagement will not have permissions to exclude this dependency. With the default behavior, even widgets instantiated with "Get.put" will be removed, unlike SmartManagement.onlyBuilders. SmartManagement.keepFactoryJust like SmartManagement.full, it will remove it's dependencies when it's not being used anymore. However, it will keep their factory, which means it will recreate the dependency if you need that instance again.
SnackbarStatus
Indicates Status of snackbar SnackbarStatus.OPEN Snack is fully open, SnackbarStatus.CLOSED Snackbar has closed, SnackbarStatus.OPENING Starts with the opening animation and ends with the full snackbar display, SnackbarStatus.CLOSING Starts with the closing animation and ends with the full snackbar dispose
SnackHoverState
Indicates if the mouse entered or exited
SnackPosition
Indicates if snack is going to start at the TOP or at the BOTTOM
SnackStyle
Indicates if snack will be attached to the edge of the screen or not
Transition

Mixins

GetPageRouteTransitionMixin<T>
IGetNavigation
PageRouteReportMixin<T>
Mixin that reports route lifecycle events to the RouterReportManager.
RouteReportMixin<T extends StatefulWidget>
Mixin that reports route lifecycle events to the RouterReportManager.
RouterListenerMixin<T extends StatefulWidget>

Constants

rtlLanguages → const List<String>
A predefined list of languages that are natively read Right-to-Left (RTL).

Properties

Get → _GetImpl
final
It replaces the Flutter Navigator, but needs no context. You can to use navigator.push(YourRoute()) rather Navigator.push(context, YourRoute());
no setter

Functions

defaultLogWriterCallback(String value, {bool isError = false}) → void
default logger from GetX
removeLastHistory(String? url) → void
setUrlStrategy() → void

Typedefs

GetPageBuilder = Widget Function()
GetRouteAwarePageBuilder<T> = Widget Function([GetPageRoute<T>? route])
LogWriterCallback = void Function(String text, {bool isError})
VoidCallback from logs
OnHover = void Function(GetSnackBar snack, SnackHoverState snackHoverState)
OnTap = void Function(GetSnackBar snack)
SnackbarStatusCallback = void Function(SnackbarStatus? status)
ValueUpdater<T> = T Function()