utils library

Get utils is a set of tools that allows you to access high-level APIs and obtain validation tools for Flutter and GetX

Classes

DeepCollectionEquality
DefaultEquality<E>
Engine
GetInterface
GetInterface allows any auxiliary package to be merged into the "Get" class through extensions
GetPlatform
GetQueue
IdentityEquality<E>
Equality of objects that compares only the identity of the objects.
IEquality<E>
A generic equality relation on objects.
IterableEquality<E>
Equality on iterables.
ListEquality<E>
Equality on lists.
MapEquality<K, V>
Equality on maps.
SetEquality<E>
Equality of sets.
UnorderedIterableEquality<E>
Equality of the elements of two iterables without considering order.

Enums

SmartManagement
GetX by default disposes unused controllers from memory, Through different behaviors. SmartManagement.full SmartManagement.full is the default one. Dispose classes that are not being used and were not set to be permanent. In the majority of the cases you will want to keep this config untouched. If you new to GetX then don't change this. SmartManagement.onlyBuilder only controllers started in init: or loaded into a Binding with Get.lazyPut() will be disposed. If you use Get.put() or Get.putAsync() or any other approach, SmartManagement will not have permissions to exclude this dependency. With the default behavior, even widgets instantiated with "Get.put" will be removed, unlike SmartManagement.onlyBuilders. SmartManagement.keepFactoryJust like SmartManagement.full, it will remove it's dependencies when it's not being used anymore. However, it will keep their factory, which means it will recreate the dependency if you need that instance again.

Mixins

Equality

Extensions

ContextExt on BuildContext
IterableExtensions on Iterable<T>
Useful extensions for Iterable.
LocalesIntl on GetInterface
LoopEventsExt on GetInterface
Trans on String

Properties

Get → _GetImpl
final

Functions

defaultLogWriterCallback(String value, {bool isError = false}) → void
default logger from GetX

Typedefs

LogWriterCallback = void Function(String text, {bool isError})
VoidCallback from logs
ValueUpdater<T> = T Function()