blur method
GetAnimatedBuilder
blur({
- double begin = 0,
- double end = 15,
- Duration duration = _defaultDuration,
- Duration delay = _defaultDelay,
- ValueSetter<
AnimationController> ? onComplete, - bool isSequential = false,
Blurs the widget from begin to end sigma factor.
beginStarting blur factor.endEnding blur factor.durationThe duration of the blur transition.delayThe delay duration before blurring starts.onCompleteA callback triggered when the animation completes.isSequentialIf true, starts this animation after the previous one in the chain completes.
Implementation
GetAnimatedBuilder blur({
double begin = 0,
double end = 15,
Duration duration = _defaultDuration,
Duration delay = _defaultDelay,
ValueSetter<AnimationController>? onComplete,
bool isSequential = false,
}) {
return BlurAnimation(
duration: duration,
delay: _getDelay(isSequential, delay),
begin: begin,
end: end,
onComplete: onComplete,
child: this,
);
}