bounce method
GetAnimatedBuilder
bounce({
- required double begin,
- required double end,
- Duration duration = _defaultDuration,
- Duration delay = _defaultDelay,
- ValueSetter<
AnimationController> ? onComplete, - bool isSequential = false,
- bool autoPlayOnUpdate = false,
Bounces the scale of the widget from begin to end.
beginStarting scale offset value.endEnding scale offset value.durationThe duration of the bounce animation.delayThe delay duration before bouncing starts.onCompleteA callback triggered when the animation completes.isSequentialIf true, starts this animation after the previous one in the chain completes.autoPlayOnUpdateIf true, replays the animation when rebuilt with a different tween.
Implementation
GetAnimatedBuilder bounce({
required double begin,
required double end,
Duration duration = _defaultDuration,
Duration delay = _defaultDelay,
ValueSetter<AnimationController>? onComplete,
bool isSequential = false,
bool autoPlayOnUpdate = false,
}) {
return BounceAnimation(
duration: duration,
delay: _getDelay(isSequential, delay),
begin: begin,
end: end,
onComplete: onComplete,
autoPlayOnUpdate: autoPlayOnUpdate,
child: this,
);
}