bounce method

GetAnimatedBuilder bounce({
  1. required double begin,
  2. required double end,
  3. Duration duration = _defaultDuration,
  4. Duration delay = _defaultDelay,
  5. ValueSetter<AnimationController>? onComplete,
  6. bool isSequential = false,
})

Bounces the scale of the widget from begin to end.

  • begin Starting scale offset value.
  • end Ending scale offset value.
  • duration The duration of the bounce animation.
  • delay The delay duration before bouncing starts.
  • onComplete A callback triggered when the animation completes.
  • isSequential If true, starts this animation after the previous one in the chain completes.

Implementation

GetAnimatedBuilder bounce({
  required double begin,
  required double end,
  Duration duration = _defaultDuration,
  Duration delay = _defaultDelay,
  ValueSetter<AnimationController>? onComplete,
  bool isSequential = false,
}) {
  return BounceAnimation(
    duration: duration,
    delay: _getDelay(isSequential, delay),
    begin: begin,
    end: end,
    onComplete: onComplete,
    child: this,
  );
}