fadeOut method
GetAnimatedBuilder
fadeOut({
- Duration duration = _defaultDuration,
- Duration delay = _defaultDelay,
- ValueSetter<
AnimationController> ? onComplete, - bool isSequential = false,
- bool autoPlayOnUpdate = false,
Animates the widget's opacity from 1.0 to 0.0.
durationThe duration of the animation transition.delayThe delay duration before the animation starts playing.onCompleteA callback triggered when the animation completes.isSequentialIf true, starts this animation after the previous one in the chain completes.autoPlayOnUpdateIf true, replays the animation when rebuilt with a different tween.
Implementation
GetAnimatedBuilder fadeOut({
Duration duration = _defaultDuration,
Duration delay = _defaultDelay,
ValueSetter<AnimationController>? onComplete,
bool isSequential = false,
bool autoPlayOnUpdate = false,
}) {
assert(
isSequential || this is! FadeInAnimation,
'Can not use fadeOut() + fadeIn when isSequential is false',
);
return FadeOutAnimation(
duration: duration,
delay: _getDelay(isSequential, delay),
onComplete: onComplete,
autoPlayOnUpdate: autoPlayOnUpdate,
child: this,
);
}