rotate method

GetAnimatedBuilder rotate({
  1. required double begin,
  2. required double end,
  3. Duration duration = _defaultDuration,
  4. Duration delay = _defaultDelay,
  5. ValueSetter<AnimationController>? onComplete,
  6. bool isSequential = false,
})

Rotates the widget from begin to end angle in radians.

  • begin Starting rotation angle in radians.
  • end Ending rotation angle in radians.
  • duration The duration of the rotation transition.
  • delay The delay duration before the rotation starts.
  • onComplete A callback triggered when the animation completes.
  • isSequential If true, starts this animation after the previous one in the chain completes.

Implementation

GetAnimatedBuilder rotate({
  required double begin,
  required double end,
  Duration duration = _defaultDuration,
  Duration delay = _defaultDelay,
  ValueSetter<AnimationController>? onComplete,
  bool isSequential = false,
}) {
  return RotateAnimation(
    duration: duration,
    delay: _getDelay(isSequential, delay),
    begin: begin,
    end: end,
    onComplete: onComplete,
    child: this,
  );
}