wave method

GetAnimatedBuilder wave({
  1. double begin = 0,
  2. double end = 1,
  3. Duration duration = _defaultDuration,
  4. Duration delay = _defaultDelay,
  5. ValueSetter<AnimationController>? onComplete,
  6. bool isSequential = false,
})

Animates the widget with a translation wave on the Y-axis.

  • begin Starting wave phase value.
  • end Ending wave phase value.
  • duration The duration of the wave transition.
  • delay The delay duration before the wave starts.
  • onComplete A callback triggered when the animation completes.
  • isSequential If true, starts this animation after the previous one in the chain completes.

Implementation

GetAnimatedBuilder wave({
  double begin = 0,
  double end = 1,
  Duration duration = _defaultDuration,
  Duration delay = _defaultDelay,
  ValueSetter<AnimationController>? onComplete,
  bool isSequential = false,
}) {
  return WaveAnimation(
    duration: duration,
    delay: _getDelay(isSequential, delay),
    begin: begin,
    end: end,
    onComplete: onComplete,
    child: this,
  );
}