get_instance/get_instance library

Classes

BindingsInterface<T>
GetxService
Unlike GetxController, which serves to control events on each of its pages, GetxService is not automatically disposed (nor can be removed with Get.delete()). It is ideal for situations where, once started, that service will remain in memory, such as Auth control for example. Only way to remove it is Get.reset().
InstanceInfo

Mixins

GetLifeCycleMixin
The GetLifeCycle
GetxServiceMixin
Allow track difference between GetxServices and GetxControllers

Typedefs

AsyncInstanceBuilderCallback<S> = Future<S> Function()
BindingBuilderCallback = void Function()
InstanceBuilderCallback<S> = S Function()
InstanceCreateBuilderCallback<S> = S Function(BuildContext _)

Exceptions / Errors

InstanceNotFoundException