BindingsInterface<T> class
abstract
An interface to define dependency injection rules for routes or specific flows.
Classes implementing BindingsInterface override the dependencies method
to register controllers, services, or other objects (typically via Get.put,
Get.lazyPut, or using Bind widgets) before a route/page is built or
when entering a specific scope.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dependencies(
) → T - Defines and registers dependencies.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited