get_instance/src/extension_instance library
Classes
- InstanceInfo
- Holds metadata about the registration and lifecycle state of an instance.
Extensions
- Inst on GetInterface
- Main extension on GetInterface providing dependency injection features.
- ResetInstance on GetInterface
- Extension on GetInterface to reset and clear registered instances.
Typedefs
-
AsyncInstanceBuilderCallback<
S> = Future< S> Function() -
Callback type for asynchronously building instances of type
S. -
InstanceBuilderCallback<
S> = S Function() -
Callback type for building singleton or lazy instances of type
S. -
InstanceCreateBuilderCallback<
S> = S Function(BuildContext _) -
Callback type for building instances of type
Son demand using BuildContext.
Exceptions / Errors
- InstanceNotFoundException
- Exception thrown when a requested dependency has not been registered in the dependency manager.