closeOverlay<T> method
Close the current overlay returning the result, if provided
Implementation
void closeOverlay<T>({String? id, T? result}) {
searchDelegate(id).navigatorKey.currentState?.pop(result);
}
Close the current overlay returning the result, if provided
void closeOverlay<T>({String? id, T? result}) {
searchDelegate(id).navigatorKey.currentState?.pop(result);
}