GetRoot class
The underlying StatefulWidget serving as the structural anchor for all GetXify apps.
GetRoot intercepts configuration from GetMaterialApp and GetCupertinoApp,
processes the ConfigData, initializes localization, translations, routing, and
theme systems before injecting them into the standard Flutter application widget.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- GetRoot
- Available extensions
Constructors
- GetRoot({Key? key, required ConfigData config, required Widget child})
-
const
Properties
- child → Widget
-
final
- config → ConfigData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- marginZero → Widget
-
Available on Widget, provided by the WidgetMarginX extension
no setter - paddingZero → Widget
-
Available on Widget, provided by the WidgetPaddingX extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sliverBox → Widget
-
Available on Widget, provided by the WidgetSliverBoxX extension
no setter
Methods
-
blur(
{double begin = 0, double end = 15, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
bounce(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< GetRoot> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
fadeIn(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
fadeOut(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
flip(
{double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
marginAll(
double margin) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingAll(
double padding) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
rotate(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
scale(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
size(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
slide(
{required OffsetBuilder offset, double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
spin(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
wave(
{double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- treeInitialized → bool
-
no setter
Static Methods
-
of(
BuildContext context) → GetRootState