get_navigation/src/root/internationalization library
Classes
- Translations
- The base abstract class used for providing localized translations to the app.
Constants
-
rtlLanguages
→ const List<
String> - A predefined list of languages that are natively read Right-to-Left (RTL).