rtlLanguages top-level constant
A predefined list of languages that are natively read Right-to-Left (RTL).
This is used internally by the GetXify entry points to automatically flip text directionality when an RTL locale is detected.
Implementation
const List<String> rtlLanguages = <String>[
'ar', // Arabic
'fa', // Farsi
'he', // Hebrew
'ps', // Pashto
'ur', // Urdu
];