get_navigation/src/routes/default_route library
Classes
-
GetPageRoute<
T>
Mixins
-
PageRouteReportMixin<
T> - Mixin that reports route lifecycle events to the RouterReportManager.
-
RouteReportMixin<
T extends StatefulWidget> - Mixin that reports route lifecycle events to the RouterReportManager.