get_navigation/src/routes/index library

Enums

PopMode
Enables the user to customize the intended pop behavior
PreventDuplicateHandlingMode
Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates
Transition

Mixins

GetPageRouteTransitionMixin<T>
IGetNavigation
PageRouteReportMixin<T>
Mixin that reports route lifecycle events to the RouterReportManager.
RouteReportMixin<T extends StatefulWidget>
Mixin that reports route lifecycle events to the RouterReportManager.
RouterListenerMixin<T extends StatefulWidget>

Functions

removeLastHistory(String? url) → void
setUrlStrategy() → void

Typedefs

GetPageBuilder = Widget Function()
GetRouteAwarePageBuilder<T> = Widget Function([GetPageRoute<T>? route])

Exceptions / Errors