get_state_manager/get_state_manager
library
Classes
-
Bind<T>
-
-
BindElement<T>
-
The BindElement is responsible for injecting dependencies into the widget
tree so that they can be observed
-
Binder<T>
-
-
Binds
-
-
CustomStatus<T>
-
-
EmptyStatus<T>
-
-
ErrorStatus<T, S>
-
-
FullLifeCycleController
-
A controller that can observe the full app lifecycle.
-
GetBuilder<T extends GetxController>
-
-
GetListenable<T>
-
-
GetNotifier<T>
-
-
GetResponsiveView<T>
-
A responsive view that extends GetView with responsive capabilities.
-
GetStatus<T>
-
Sealed class representing different states of a notifier.
-
GetTickerProvider
-
Common interface of GetSingleTickerProviderStateMixin and
GetTickerProviderStateMixin: a TickerProvider whose tickers follow
the TickerMode of the widget subtree that forwards its dependency
changes to didChangeDependencies.
-
GetView<T>
-
GetView is a lightweight StatelessWidget providing easy access to a controller
registered in dependency injection without calling
Get.find<Controller>() manually.
-
GetxController
-
A base controller class that provides state management functionality.
-
LoadingStatus<T>
-
-
Observer
-
An experimental widget that observes reactive changes.
-
Obx
-
The simplest reactive widget in GetX.
-
ObxElement
-
Element for Obx widgets that tracks reactive dependencies.
-
ObxStatelessWidget
-
A StatelessWidget that can listen to reactive changes.
-
ObxValue<T extends RxInterface>
-
Similar to Obx, but manages a local state.
Pass the initial data in constructor.
Useful for simple local states, like toggles, visibility, themes,
button states, etc.
Sample:
ObxValue((data) => Switch(
value: data.value,
onChanged: (flag) => data.value = flag,
),
false.obs,
),
-
ObxWidget
-
The ObxWidget is the base for all GetX reactive widgets
-
ResponsiveScreen
-
Provides information about the current screen.
-
ResponsiveScreenSettings
-
Settings for responsive screen breakpoints.
-
RxController
-
A base controller class for reactive state management using Rx variables.
-
StateController<T>
-
A controller that manages state for asynchronous operations.
-
SuccessStatus<T>
-
-
SuperController<T>
-
A controller that combines full lifecycle management with state management.
-
Value<T>
-
-
ValueBuilder<T>
-
Manages a local state like ObxValue, but uses a callback instead of
a Rx value.
-
ValueBuilderState<T>
-
The state for ValueBuilder.
Enums
-
ScreenType
-
Enum representing different screen types.