get_state_manager/get_state_manager library

Classes

Bind<T>
BindElement<T>
The BindElement is responsible for injecting dependencies into the widget tree so that they can be observed
Binder<T>
Binding
Binding should be extended. When using GetMaterialApp, all GetPages and navigation methods (like Get.to()) have a binding property that takes an instance of Bindings to manage the dependencies() (via Get.put()) for the Route you are opening.
Binds
CustomStatus<T>
Represents a custom status.
EmptyStatus<T>
Represents an empty status.
ErrorStatus<T, S>
Represents an error status with an error object.
FullLifeCycleController
A controller that can observe the full app lifecycle.
GetBuilder<T extends GetxController>
GetListenable<T>
A listenable that implements RxInterface for reactive programming.
GetNotifier<T>
A notifier with status, state, and GetX lifecycle support.
GetResponsiveView<T>
A responsive view that extends GetView with responsive capabilities.
GetResponsiveWidget<T extends GetLifeCycleMixin>
A responsive widget that extends GetWidget with responsive capabilities.
GetStatus<T>
Sealed class representing different states of a notifier.
GetView<T>
GetView is a great way of quickly access your Controller without having to call Get.find<AwesomeController>() yourself.
GetWidget<S extends GetLifeCycleMixin>
GetWidget is a great way of quickly access your individual Controller without having to call Get.find<AwesomeController>() yourself. Get save you controller on cache, so, you can to use Get.create() safely GetWidget is perfect to multiples instance of a same controller. Each GetWidget will have your own controller, and will be call events as onInit and onClose when the controller get in/get out on memory.
GetX<T extends GetLifeCycleMixin>
A StatefulWidget that provides reactive state management.
GetxController
A base controller class that provides state management functionality.
GetXState<T extends GetLifeCycleMixin>
The state for a GetX widget.
LoadingStatus<T>
Represents a loading status.
Observer
An experimental widget that observes reactive changes.
Obx
The simplest reactive widget in GetX.
ObxElement
Element for Obx widgets that tracks reactive dependencies.
ObxStatelessWidget
A StatelessWidget that can listen to reactive changes.
ObxValue<T extends RxInterface>
Similar to Obx, but manages a local state. Pass the initial data in constructor. Useful for simple local states, like toggles, visibility, themes, button states, etc. Sample: ObxValue((data) => Switch( value: data.value, onChanged: (flag) => data.value = flag, ), false.obs, ),
ObxWidget
The ObxWidget is the base for all GetX reactive widgets
ResponsiveScreen
Provides information about the current screen.
ResponsiveScreenSettings
Settings for responsive screen breakpoints.
RxController
A base controller class for reactive state management using Rx variables.
StateController<T>
A controller that manages state for asynchronous operations.
SuccessStatus<T>
Represents a success status with data.
SuperController<T>
A controller that combines full lifecycle management with state management.
Value<T>
A value that can be listened to and has status tracking.
ValueBuilder<T>
Manages a local state like ObxValue, but uses a callback instead of a Rx value.
ValueBuilderState<T>
The state for ValueBuilder.

Enums

ScreenType
Enum representing different screen types.

Mixins

FullLifeCycleMixin
A mixin that provides full lifecycle callbacks for the controller.
GetResponsiveMixin
Mixin that provides responsive building capabilities.
GetSingleTickerProviderStateMixin
Used like SingleTickerProviderMixin but only with Get Controllers. Simplifies AnimationController creation inside GetxController.
GetTickerProviderStateMixin
Used like TickerProviderMixin but only with Get Controllers. Simplifies multiple AnimationController creation inside GetxController.
ScrollMixin
A mixin that provides scroll-based data fetching capabilities.
StatelessObserverComponent
Mixin that adds reactive tracking to StatelessElement.
StateMixin<T>
Mixin that adds state management with status tracking.

Extensions

ReadExt on BuildContext
StateExt on StateMixin<T>
Extension on StateMixin that provides a widget builder.
StatusDataExt on GetStatus<T>
Extension on GetStatus providing convenience getters.
WatchExt on BuildContext

Typedefs

FuturizeCallback<T> = Future<T> Function(VoidCallback fn)
GetControllerBuilder<T extends GetLifeCycleMixin> = Widget Function(T controller)
GetXControllerBuilder<T extends GetLifeCycleMixin> = Widget Function(T controller)
Builder function for GetX widgets.
InitBuilder<T> = T Function()
NotifierBuilder<T> = Widget Function(T state)
Builder function for notifier widgets.
ValueBuilderBuilder<T> = Widget Function(T snapshot, ValueBuilderUpdateCallback<T> updater)
Builder function for ValueBuilder.
ValueBuilderUpdateCallback<T> = void Function(T snapshot)
Callback function to update the value in ValueBuilder.
VoidCallback = void Function()
WidgetCallback = Widget Function()

Exceptions / Errors

BindError<T>