GetX<T extends GetLifeCycleMixin> class

A StatefulWidget that provides reactive state management.

This widget automatically manages the lifecycle of a controller and rebuilds when the controller's state changes. It supports both global and local controller management.

Inheritance
Available extensions

Constructors

GetX({Key? key, String? tag, required GetXControllerBuilder<T> builder, bool global = true, bool autoRemove = true, void initState(GetXState<T> state)?, bool assignId = false, void dispose(GetXState<T> state)?, void didChangeDependencies(GetXState<T> state)?, void didUpdateWidget(GetX<GetLifeCycleMixin> oldWidget, GetXState<T> state)?, T? init})
Creates a new GetX widget.
const

Properties

assignId bool
Whether to assign a unique ID to this widget instance.
final
autoRemove bool
Whether to automatically remove the controller when the widget is disposed.
final
builder GetXControllerBuilder<T>
Builder function that creates the widget tree.
final
didChangeDependencies → void Function(GetXState<T> state)?
Callback called when the state is initialized.
final
didUpdateWidget → void Function(GetX<GetLifeCycleMixin> oldWidget, GetXState<T> state)?
Callback called when the widget updates.
final
dispose → void Function(GetXState<T> state)?
Callback called when the state is initialized.
final
global bool
Whether the controller is global (shared across the app).
final
hashCode int
The hash code for this object.
no setterinherited
init → T?
The initial controller instance.
final
initState → void Function(GetXState<T> state)?
Callback called when the state is initialized.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
The tag to identify the controller in the dependency injection system.
final

Methods

blur({double begin = 0, double end = 15, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

bounce({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
override
createState() GetXState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
fadeIn({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

fadeOut({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

flip({double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

scale({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

size({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

slide({required OffsetBuilder offset, double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

spin({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
wave({double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited