GetStatus<T> class
sealed
Sealed class representing different states of a notifier.
- Mixed-in types
- Implementers
- Available extensions
Constructors
- GetStatus.custom()
-
factory
- GetStatus.empty()
-
factory
- GetStatus.error(Object message)
-
factory
- GetStatus.loading()
-
factory
- GetStatus.success(T data)
-
factory
Properties
- data → T?
-
no setter
- error → Object?
-
no setter
- errorMessage → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCustom → bool
-
no setter
- isEmpty → bool
-
no setter
- isError → bool
-
no setter
- isLoading → bool
-
no setter
- isSuccess → bool
-
no setter
-
props
→ List<
Object?> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
maybeWhen<
R> ({required R orElse(), R loading()?, R success(T data)?, R error(Object? error)?, R empty()?, R custom()?}) → R -
Available on GetStatus<
T> , provided by the StatusDataExt extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
R> ({required R loading(), required R success(T data), required R error(Object? error), required R empty(), R custom()?}) → R -
Available on GetStatus<
T> , provided by the StatusDataExt extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited