GetStatus<T> class
sealed
Sealed class representing different states of a notifier.
This class provides a type-safe way to represent different states: loading, error, empty, success, and custom.
- Mixed-in types
- Implementers
- Available extensions
Constructors
- GetStatus.custom()
-
Creates a custom status.
factory
- GetStatus.empty()
-
Creates an empty status.
factory
- GetStatus.error(Object message)
-
Creates an error status with a message.
factory
- GetStatus.loading()
-
Creates a loading status.
factory
- GetStatus.success(T data)
-
Creates a success status with data.
factory
Properties
- data → T?
-
Available on GetStatus<
The data if this is a success status.T> , provided by the StatusDataExt extensionno setter - error → Object?
-
Available on GetStatus<
The error object if this is an error status.T> , provided by the StatusDataExt extensionno setter - errorMessage → String
-
Available on GetStatus<
The error message as a string.T> , provided by the StatusDataExt extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isCustom → bool
-
Available on GetStatus<
Whether this status is custom.T> , provided by the StatusDataExt extensionno setter - isEmpty → bool
-
Available on GetStatus<
Whether this status is empty.T> , provided by the StatusDataExt extensionno setter - isError → bool
-
Available on GetStatus<
Whether this status is error.T> , provided by the StatusDataExt extensionno setter - isLoading → bool
-
Available on GetStatus<
Whether this status is loading.T> , provided by the StatusDataExt extensionno setter - isSuccess → bool
-
Available on GetStatus<
Whether this status is success.T> , provided by the StatusDataExt extensionno setter -
props
→ List<
Object?> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited