StateMixin<T> mixin
Mixin that adds state management with status tracking.
This mixin provides a way to manage state with loading, error, success, and empty statuses. It's commonly used with controllers that handle async operations.
- Superclass constraints
- Mixin applications
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
no setterinherited
- listenersLength → int
-
Returns the number of active listeners.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → T
-
Alias for value for convenience.
no setter
-
status
↔ GetStatus<
T> -
The current status of the state.
getter/setter pair
- value ↔ T
-
The current value of the state.
getter/setter pair
Methods
-
addListener(
GetStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, GetStateUpdate listener) → Disposer -
Adds a listener to a specific group identified by
key.inherited -
change(
GetStatus< T> status) → void - Changes the status if it's different from the current status.
-
containsId(
Object id) → bool -
Checks if a listener group with the given ID exists.
inherited
-
containsListener(
GetStateUpdate listener) → bool -
inherited
-
dispose(
) → void -
Disposes all listener groups.
inherited
-
disposeId(
Object id) → void -
Disposes a specific listener group.
inherited
-
futurize(
Future< T> body(), {T? initialData, String? errorMessage, bool useEmpty = true}) → void - Executes a future and automatically handles status changes.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyGroupChildrens(
Object id) → void -
Reports that a listener group was read.
inherited
-
obx(
NotifierBuilder< T> widget, {Widget onError(String? error)?, Widget? onLoading, Widget? onEmpty, WidgetBuilder? onCustom}) → Widget -
Available on StateMixin<
Builds a widget based on the current status.T> , provided by the StateExt extension -
refresh(
) → void -
Notifies all listeners to update.
inherited
-
refreshGroup(
Object id) → void -
Refreshes only the listeners in a specific group.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
Removes a listener from a specific group.
inherited
-
reportAdd(
VoidCallback disposer) → void -
Reports a disposer callback to the global notifier.
inherited
-
reportRead(
) → void -
Reports that this notifier was read.
inherited
-
setEmpty(
) → void - Sets the status to empty.
-
setError(
Object error) → void - Sets the status to error with the given error object.
-
setLoading(
) → void - Sets the status to loading.
-
setSuccess(
T data) → void - Sets the status to success with the given data.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited