GetxController class abstract

A base controller class that provides state management functionality.

Extend this class to create a controller that can be used with GetX's state management system. This class provides methods to update the UI when the controller's state changes.

Example:

class CounterController extends GetxController {
  var count = 0;

  void increment() {
    count++;
    update(); // Triggers UI update
  }
}
Inheritance
Mixed-in types
Implementers

Constructors

GetxController()

Properties

hashCode int
The hash code for this object.
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDisposed bool
no setterinherited
listenersLength int
Returns the number of active listeners.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(GetStateUpdate listener) Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) Disposer
Adds a listener to a specific group identified by key.
inherited
containsId(Object id) bool
Checks if a listener group with the given ID exists.
inherited
containsListener(GetStateUpdate listener) bool
inherited
dispose() → void
Disposes all listener groups.
inherited
disposeId(Object id) → void
Disposes a specific listener group.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyGroupChildrens(Object id) → void
Reports that a listener group was read.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onDelete() → void
Called when the controller is removed from memory.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onStart() → void
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
inherited
refresh() → void
Notifies all listeners to update.
inherited
refreshGroup(Object id) → void
Refreshes only the listeners in a specific group.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
Removes a listener from a specific group.
inherited
reportAdd(VoidCallback disposer) → void
Reports a disposer callback to the global notifier.
inherited
reportRead() → void
Reports that this notifier was read.
inherited
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Notifies listeners to update the UI.

Operators

operator ==(Object other) bool
The equality operator.
inherited