GetResponsiveMixin mixin

Mixin that provides responsive building capabilities.

This mixin allows widgets to build different UI based on the screen type (desktop, tablet, phone, watch). It provides methods to build specific UI for each screen type.

Superclass constraints
Mixin applications
Available extensions

Properties

alwaysUseBuilder bool
Whether to always use the builder method.
no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen ResponsiveScreen
The responsive screen information.
no setter

Methods

blur({double begin = 0, double end = 15, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Blurs the widget from begin to end sigma factor.
bounce({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Bounces the scale of the widget from begin to end.
build(BuildContext context) Widget
builder() Widget?
Builds the widget using the builder method.
createElement() Element
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
desktop() Widget?
Builds the widget for desktop screens.
fadeIn({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Animates the widget's opacity from 0.0 to 1.0.
fadeOut({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Animates the widget's opacity from 1.0 to 0.0.
flip({double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Flips the widget around the Y-axis from begin to end.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
phone() Widget?
Builds the widget for phone screens.
rotate({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Rotates the widget from begin to end angle in radians.
scale({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Scales the widget from begin to end factor.
size({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Animates the widget's layout size/scale from begin to end.
slide({required OffsetBuilder offset, double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Translates/slides the widget dynamically using an offset builder.
spin({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Spins the widget 360 degrees.
tablet() Widget?
Builds the widget for tablet screens.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
watch() Widget?
Builds the widget for watch screens.
wave({double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Animates the widget with a translation wave on the Y-axis.

Operators

operator ==(Object other) bool
The equality operator.
inherited