GetResponsiveView<T> class
A responsive view that extends GetView with responsive capabilities.
This widget provides the screen property that contains all
information about the screen size and type. You have two options
to build it:
- Use the
buildermethod to return the widget to build - Use the specific methods
desktop,tablet,phone,watchwhich will be called when the screen type matches
Note: If you use the specific methods, set alwaysUseBuilder to false.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GetView<
T> - GetResponsiveView
- Mixed-in types
- Available extensions
Constructors
- GetResponsiveView({bool alwaysUseBuilder = false, ResponsiveScreenSettings settings = const ResponsiveScreenSettings(), Key? key})
Properties
- alwaysUseBuilder → bool
-
Whether to always use the builder method.
final
- controller → T
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screen → ResponsiveScreen
-
The responsive screen information.
final
- tag → String?
-
finalinherited
Methods
-
blur(
{double begin = 0, double end = 15, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
bounce(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
build(
BuildContext context) → Widget -
inherited
-
builder(
) → Widget? -
Builds the widget using the builder method.
inherited
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
desktop(
) → Widget? -
Builds the widget for desktop screens.
inherited
-
fadeIn(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
fadeOut(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
flip(
{double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
phone(
) → Widget? -
Builds the widget for phone screens.
inherited
-
rotate(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
scale(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
size(
{required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
slide(
{required OffsetBuilder offset, double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
spin(
{Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
-
tablet(
) → Widget? -
Builds the widget for tablet screens.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
watch(
) → Widget? -
Builds the widget for watch screens.
inherited
-
wave(
{double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter< AnimationController> ? onComplete, bool isSequential = false}) → GetAnimatedBuilder -
Available on Widget, provided by the AnimationExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited