ResponsiveScreenSettings class
Settings for responsive screen breakpoints.
This class defines the width thresholds for different screen types.
Constructors
- ResponsiveScreenSettings({double desktopChangePoint = 1200, double tabletChangePoint = 600, double watchChangePoint = 300})
-
const
Properties
- desktopChangePoint → double
-
When the width is greater than this value, the display will be set as ScreenType.desktop.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabletChangePoint → double
-
When the width is greater than this value, the display will be set as ScreenType.tablet,
or when width is greater than watchChangePoint and smaller than this value,
the display will be ScreenType.phone.
final
- watchChangePoint → double
-
When the width is smaller than this value, the display will be set as ScreenType.watch,
or when width is greater than this value and smaller than tabletChangePoint,
the display will be ScreenType.phone.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited