watchChangePoint property
When the width is smaller than this value, the display will be set as ScreenType.watch, or when width is greater than this value and smaller than tabletChangePoint, the display will be ScreenType.phone.
Implementation
final double watchChangePoint;