Bind<T> class abstract

Inheritance
Available extensions

Constructors

Bind({Key? key, required Widget? child, InitBuilder<T>? init, bool global = true, bool autoRemove = true, bool assignId = false, void initState(BindElement<T> state)?, Object filter(T value)?, String? tag, void dispose(BindElement<T> state)?, Object? id, void didChangeDependencies(BindElement<T> state)?, void didUpdateWidget(Binder<T> oldWidget, BindElement<T> state)?})
const
Bind.builder({Widget? child, InitBuilder<T>? init, InstanceCreateBuilderCallback<T>? create, bool global = true, bool autoRemove = true, bool assignId = false, Object filter(T value)?, String? tag, Object? id, void initState(BindElement<T> state)?, void dispose(BindElement<T> state)?, void didChangeDependencies(BindElement<T> state)?, void didUpdateWidget(Binder<T> oldWidget, BindElement<T> state)?})
factory

Properties

assignId bool
final
autoRemove bool
final
child Widget?
final
didChangeDependencies → void Function(BindElement<T> state)?
final
didUpdateWidget → void Function(Binder<T> oldWidget, BindElement<T> state)?
final
dispose → void Function(BindElement<T> state)?
final
filter Object Function(T value)?
final
global bool
final
hashCode int
The hash code for this object.
no setterinherited
id Object?
final
init InitBuilder<T>?
final
initState → void Function(BindElement<T> state)?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
final

Methods

blur({double begin = 0, double end = 15, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

bounce({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fadeIn({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

fadeOut({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

flip({double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

scale({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

size({required double begin, required double end, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

slide({required OffsetBuilder offset, double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

spin({Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
wave({double begin = 0, double end = 1, Duration duration = _defaultDuration, Duration delay = _defaultDelay, ValueSetter<AnimationController>? onComplete, bool isSequential = false}) GetAnimatedBuilder

Available on Widget, provided by the AnimationExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fenixMode bool
getter/setter pair

Static Methods

create<S>(InstanceCreateBuilderCallback<S> builder, {String? tag, bool permanent = true}) Bind
delete<S>({String? tag, bool force = false}) Future<bool>
deleteAll({bool force = false}) Future<void>
find<S>({String? tag}) → S
isPrepared<S>({String? tag}) bool
isRegistered<S>({String? tag}) bool
lazyPut<S>(InstanceBuilderCallback<S> builder, {String? tag, bool? fenix, VoidCallback? onClose}) Bind
lazyReplace<P>(InstanceBuilderCallback<P> builder, {String? tag, bool? fenix}) → void
of<T>(BuildContext context, {bool rebuild = false}) → T
put<S>(S dependency, {String? tag, bool permanent = false}) Bind
reload<S>({String? tag, String? key, bool force = false}) → void
reloadAll({bool force = false}) → void
replace<P>(P child, {String? tag}) → void
spawn<S>(InstanceBuilderCallback<S> builder, {String? tag, bool permanent = true}) Bind