createWidgetCache method
Creates the WidgetCache instance for this widget.
This method is called when the element is created and should return a new instance of the cache that will manage this widget's state.
Implementation
@override
WidgetCache createWidgetCache() => _GetCache<S>();