get_state_manager/src/simple/list_notifier library

Classes

ListNotifier
A notifier that combines single and group listener capabilities.
ListNotifierGroup
A notifier with group listener support identified by ID.
ListNotifierSingle
A notifier with single listener support.
Notifier
Singleton that manages reactive dependencies.
NotifyData
Data container for reactive notification tracking.

Mixins

ListNotifierGroupMixin
Mixin that adds group listener functionality to Listenable.
ListNotifierSingleMixin
Mixin that adds single listener functionality to Listenable.

Typedefs

Disposer = void Function()
Callback function to remove a listener.
GetStateUpdate = void Function()
Callback function to update state.