ListNotifierGroupMixin mixin
Mixin that adds group listener functionality to ChangeNotifier.
- Superclass constraints
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
addListenerId(
Object? key, VoidCallback listener) → Disposer -
Adds a listener to a specific group identified by
key. -
containsId(
Object id) → bool - Checks if a listener group with the given ID exists.
-
dispose(
) → void -
Disposes all listener groups.
override
-
disposeId(
Object id) → void - Disposes a specific listener group.
-
ensureGroupListenable(
Object id) → ChangeNotifier -
Ensures a group ChangeNotifier exists for
idand returns it. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyGroupChildrens(
Object id) → void - Reports that a listener group was read.
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
refreshGroup(
Object id) → void - Refreshes only the listeners in a specific group.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void - Removes a listener from a specific group.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited