ListNotifierGroupMixin mixin
Mixin that adds group listener functionality to Listenable.
This mixin provides listener management where listeners can be grouped by an ID. This allows for selective updates of specific listener groups rather than all listeners.
- Superclass constraints
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, GetStateUpdate listener) → Disposer -
Adds a listener to a specific group identified by
key. -
containsId(
Object id) → bool - Checks if a listener group with the given ID exists.
-
dispose(
) → void - Disposes all listener groups.
-
disposeId(
Object id) → void - Disposes a specific listener group.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyGroupChildrens(
Object id) → void - Reports that a listener group was read.
-
refreshGroup(
Object id) → void - Refreshes only the listeners in a specific group.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void - Removes a listener from a specific group.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited