ListNotifierSingle class
A notifier with single listener support.
This is a type alias for ListNotifier with only the ListNotifierSingleMixin mixed in, providing basic single listener functionality.
- Inheritance
-
- Object
- Listenable
- ListNotifier
- ListNotifierSingle
- Mixed-in types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
no setterinherited
- listenersLength → int
-
Returns the number of active listeners.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
GetStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, GetStateUpdate listener) → Disposer -
Adds a listener to a specific group identified by
key.inherited -
containsId(
Object id) → bool -
Checks if a listener group with the given ID exists.
inherited
-
containsListener(
GetStateUpdate listener) → bool -
inherited
-
dispose(
) → void -
Disposes the notifier and removes all listeners.
inherited
-
disposeId(
Object id) → void -
Disposes a specific listener group.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyGroupChildrens(
Object id) → void -
Reports that a listener group was read.
inherited
-
refresh(
) → void -
Notifies all listeners to update.
inherited
-
refreshGroup(
Object id) → void -
Refreshes only the listeners in a specific group.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
Removes a listener from a specific group.
inherited
-
reportAdd(
VoidCallback disposer) → void -
Reports a disposer callback to the global notifier.
inherited
-
reportRead(
) → void -
Reports that this notifier was read.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited