ListNotifierSingleMixin mixin
Mixin that adds single listener functionality to Listenable.
This mixin provides the core listener management for a single listener group, including addListener, removeListener, and containsListener methods.
- Superclass constraints
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
no setter
- listenersLength → int
-
Returns the number of active listeners.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
GetStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
override
-
containsListener(
GetStateUpdate listener) → bool -
dispose(
) → void - Disposes the notifier and removes all listeners.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → void - Notifies all listeners to update.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
override
-
reportAdd(
VoidCallback disposer) → void - Reports a disposer callback to the global notifier.
-
reportRead(
) → void - Reports that this notifier was read.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited