dispose method
Disposes the notifier and removes all listeners.
After calling this method, the notifier can no longer be used. Any attempt to use it will throw an error.
Implementation
@mustCallSuper
void dispose() {
assert(_debugAssertNotDisposed());
_updaters = null;
}