Trans extension
- on
Methods
-
trArgs(
[List< String> args = const []]) → String -
trParams(
[Map< String, String> params = const {}]) → String -
Available on String, provided by the Trans extension
Translates this key with tr, then replaces every@nameplaceholder in the result with the value mapped tonameinparams. -
trPlural(
[String? pluralKey, int? i, List< String> args = const []]) → String -
trPluralCases(
Map< PluralCase, String> caseKeys, int count, [List<String> args = const []]) → String -
Available on String, provided by the Trans extension
Translates the plural form of this key that matchescount, supporting every CLDR plural category — unlike trPlural, which only distinguishescount == 1from everything else. -
trPluralCasesParams(
Map< PluralCase, String> caseKeys, int count, [Map<String, String> params = const {}]) → String -
Available on String, provided by the Trans extension
Translates the plural form of this key that matchescount, like trPluralCases, but substitutes named@placeholderparameters via trParams andparamsinstead of positional%sarguments. -
trPluralParams(
[String? pluralKey, int? i, Map< String, String> params = const {}]) → String